From df618da530cccfcf5829abe009df875f57cbf8ec Mon Sep 17 00:00:00 2001
From: Dennis1993 <marvin-wegener@outlook.com>
Date: Tue, 06 Aug 2013 13:23:36 -0400
Subject: [PATCH] Update compose.html
---
plugins/debug_logger/debug_logger.php | 20 ++++++++++++--------
1 files changed, 12 insertions(+), 8 deletions(-)
diff --git a/plugins/debug_logger/debug_logger.php b/plugins/debug_logger/debug_logger.php
index 8cd3351..deb6deb 100644
--- a/plugins/debug_logger/debug_logger.php
+++ b/plugins/debug_logger/debug_logger.php
@@ -12,16 +12,16 @@
* which can redirect messages to files. The resulting log files
* provide timing and tag quantity results.
*
- * Enable the plugin in config/main.inc.php and add your desired
+ * Enable the plugin in config.inc.php and add your desired
* log types and files.
*
- * @version 1.0
+ * @version @package_version@
* @author Ziba Scott
* @website http://roundcube.net
*
* Example:
*
- * config/main.inc.php:
+ * config.inc.php:
*
* // $rcmail_config['debug_logger'][type of logging] = name of file in log_dir
* // The 'master' log includes timing information
@@ -106,12 +106,15 @@
if(!isset($args[1])){
// This could be extended to detect types based on the
- // file which called console. For now only rcube_imap.inc is supported
- $bt = debug_backtrace(true);
+ // file which called console. For now only rcube_imap/rcube_storage is supported
+ $bt = debug_backtrace();
$file = $bt[3]['file'];
switch(basename($file)){
case 'rcube_imap.php':
$type = 'imap';
+ break;
+ case 'rcube_storage.php':
+ $type = 'storage';
break;
default:
$type = FALSE;
@@ -139,8 +142,9 @@
return $args;
}
- function __destruct(){
- $this->runlog->end();
+ function __destruct()
+ {
+ if ($this->runlog)
+ $this->runlog->end();
}
}
-?>
--
Gitblit v1.9.1